@@ -3,7 +3,7 @@ IMGO - Compile, process, and augment image data.
 -------------------------------------------------
 AUGTOOLS module: 
 
-Last updated: version 2.0.2
+Last updated: version 2.2.0
 
 Classes
 -------        
@@ -19,6 +19,12 @@ Augmenter: Class representing an image augmentation system.
         dropout_pair (list or tuple): amount and degree of random pixel 
         dropout applied.
         -
+        x_scale (list or tuple): range relative to image size from which 
+        a random x-axis rescale value is drawn.
+        -
+        y_scale (list or tuple): range relative to image size from which 
+        a random y-axis rescale value is drawn.
+        -
         x_shift (list or tuple): range relative to image size from which 
         a random x-axis translation is drawn.
         -
@@ -52,7 +58,10 @@ Augmenter: Class representing an image augmentation system.
         sharpness (bool): whether or not random sharpness adjustment is 
         applied.
         -
-        randomize_batch (bool): whether the augmentation parameters 
+        fill_mode (str): which method is used to fill pixels created by 
+        any of the augmentation functions.
+        -
+        randomize_params (bool): whether the augmentation parameters 
         applied are fixed as the input given or are randomly drawn from a 
         range inferred from the input given.
         -
@@ -73,6 +82,10 @@ Augmenter: Class representing an image augmentation system.
         -
         aug_dropout: apply imgaug CoarseDropout to image.
         -
+        aug_x_scale: apply imgaug ScaleX to image.
+        -
+        aug_y_scale: apply imgaug ScaleY to image.
+        -
         aug_x_shift: apply imgaug TranslateX to image.
         -
         aug_y_shift: apply imgaug TranslateY to image.
@@ -143,6 +156,12 @@ class Augmenter:
     dropout_pair (list or tuple): amount and degree of random pixel
     dropout applied.
     -
+    x_scale (list or tuple): range relative to image size from which a
+    random x-axis rescale value is drawn.
+    -
+    y_scale (list or tuple): range relative to image size from which a
+    random y-axis rescale value is drawn.
+    -
     x_shift (list or tuple): range relative to image size from which a
     random x-axis translation is drawn.
     -
@@ -175,7 +194,10 @@ class Augmenter:
     sharpness (bool): whether or not random sharpness adjustment is
     applied.
     -
-    randomize_batch (bool): whether the augmentation parameters applied
+    fill_mode (str): which method is used to fill pixels created by any of
+    the augmentation functions.
+    -
+    randomize_params (bool): whether the augmentation parameters applied
     are fixed as the input given or are randomly drawn from a range
     inferred from the input given.
     -
@@ -195,6 +217,10 @@ class Augmenter:
     -
     aug_dropout: apply imgaug CoarseDropout to image.
     -
+    aug_x_scale: apply imgaug ScaleX to image.
+    -
+    aug_y_scale: apply imgaug ScaleY to image.
+    -
     aug_x_shift: apply imgaug TranslateX to image.
     -
     aug_y_shift: apply imgaug TranslateY to image.
@@ -232,6 +258,8 @@ class Augmenter:
         rotate_range=None,
         shear_range=None,
         dropout_pair=None,
+        x_scale=None,
+        y_scale=None,
         x_shift=None,
         y_shift=None,
         clip_limit=None,
@@ -243,7 +271,8 @@ class Augmenter:
         e_sev=None,
         contrast=False,
         sharpness=False,
-        randomize_batch=False,
+        fill_mode=None,
+        randomize_params=False,
     ):
 
         """
@@ -252,19 +281,19 @@ class Augmenter:
         Once initialized, the augmenter applies one or more augmentation
         functions to the image, depending on which keyword arguments are
         given, in a random order. If the batch is randomized (specified
-        with the randomize_batch argument), the functions will be applied
+        with the randomize_params argument), the functions will be applied
         using a random parameter inferred from the argument given.
 
         Note that in order to be augmented, images must be in non-
         normalized.
 
         Keyword Arguments:
-            rotate_range (list or tuple) optional: range (min,max) in
+            rotate_range (list or tuple) optional: range (min, max) in
             degrees from which a random rotation angle is drawn. The
             corresponding aug_rotate function will rotate each image by
             a randomly chosen angle within this range. Defaults to None.
             -
-            shear_range (list or tuple) optional: range (min,max) in
+            shear_range (list or tuple) optional: range (min, max) in
             degrees from which a random shear angle is drawn. The
             corresponding aug_shear function will apply a shear
             adjustment to each image at a randomly chosen angle within
@@ -278,6 +307,16 @@ class Augmenter:
             drop the pixels (thereby increasing the size of the dropped
             portions). Defaults to None.
             -
+            x_scale (list or tuple) optional: range (min, max)
+            proportional to image size from which an x-axis scale value is
+            drawn. The corresponding aug_x_scale function will scale the
+            image to this value along the x-axis. Defaults to None.
+            -
+            y_scale (list or tuple) optional: range (min, max)
+            proportional to image size from which an y-axis scale value is
+            drawn. The corresponding aug_y_scale function will scale the
+            image to this value along the y-axis. Defaults to None.
+            -
             x_shift (list or tuple) optional: range relative
             to image size from which a random x-axis translation is drawn.
             The corresponding aug_x_shift function will shift each image
@@ -343,7 +382,14 @@ class Augmenter:
             a random proportion of the images will be adjusted by the
             corresponding aug_sharpness function. Defaults to False.
             -
-            randomize_batch (bool) optional: whether the
+            fill_mode (str) optional: which method to use to fill any
+            pixels created by any of the augmentation functions. Choose
+            from "edge" (fills with the same value as that of the edge of
+            the array), or "reflect" (reflects the pixel values along edge
+            of the array). If None, will fill with a constant value.
+            Defaults to None.
+            -
+            randomize_params (bool) optional: whether the
             augmentation parameters applied are fixed as the input given
             or are randomly drawn from a range inferred from the input
             given. If False, the same transformation parameters will be
@@ -356,13 +402,14 @@ class Augmenter:
         # Note: if adding augmentation functions, be sure to add to:
         # (1) __init__ arguments
         # (2) setattribute dictionaries
-        # (3) self.f_list, and
-        # (4) the function itself
+        # (3) the function itself
 
         for k, v in {
             "rotate_range": rotate_range,
             "shear_range": shear_range,
             "dropout_pair": dropout_pair,
+            "x_scale": x_scale,
+            "y_scale": y_scale,
             "x_shift": x_shift,
             "y_shift": y_shift,
             "clip_limit": clip_limit,
@@ -394,7 +441,7 @@ class Augmenter:
         for k, v in {
             "contrast": contrast,
             "sharpness": sharpness,
-            "randomize_batch": randomize_batch,
+            "randomize_params": randomize_params,
         }.items():
 
             if v == True:
@@ -402,22 +449,26 @@ class Augmenter:
             else:
                 setattr(self, k, False)
 
-        self.f_list = [
-            self.aug_rotate,
-            self.aug_shear,
-            self.aug_dropout,
-            self.aug_x_shift,
-            self.aug_y_shift,
-            self.aug_clahe,
-            self.aug_pwa,
-            self.aug_h_flip,
-            self.aug_v_flip,
-            self.aug_g_noise,
-            self.aug_brightness,
-            self.aug_elastic,
-            self.aug_contrast,
-            self.aug_sharpness,
-        ]
+        if fill_mode is not None:
+            if fill_mode in ["edge", "reflect"]:
+                self.fill_mode = fill_mode
+            else:
+                raise Exception(
+                    "Please select valid 'fill_mode': 'edge', or 'reflect'."
+                )
+                self.fill_mode = "constant"
+        else:
+            self.fill_mode = "constant"
+
+        f_names = sorted(
+            [
+                f
+                for f in dir(self)
+                if callable(getattr(self, f)) and f.startswith("aug_")
+            ],
+            key=lambda f: f.lower(),
+        )
+        self.f_list = [getattr(self, i) for i in f_names]
 
         self.argno = len(self.f_list)
 
@@ -426,37 +477,45 @@ class Augmenter:
     def details(self):
 
         """
-        Prints summary of parameters with which the augmenter was
+        Prints summary of parameters with which the selfmenter was
         initialized.
         """
 
-        exclude_keys = ["f_list", "argno", "randomize_batch"]
-        sum_dict = {
-            k: vars(self)[k]
-            for k in set(list(vars(self).keys())) - set(exclude_keys)
-        }
-
+        exclude_set = set(
+            ["f_list", "argno", "randomize_params", "fill_mode"]
+        )
+        param_list = sorted(
+            list(set([k for k in vars(self).keys()]) - exclude_set),
+            key=lambda f: f.lower(),
+        )
+        add_list = ["fill_mode", "randomize_params"]
         print(
             "Augmenter initialized with the following parameter ranges:"
         )
-        print("----------")
         print(
-            "\n".join(
-                "{}: {}".format(k, v) for k, v in sum_dict.items()
-            )
+            "----------------------------------------------------------"
         )
+        for i in param_list:
+            val = str(vars(self)[i])
+            print(f"{i:<20}{val}")
+        print("-")
+        for i in add_list:
+            val = str(vars(self)[i])
+            print(f"{i:<20}{val}")
 
     #     ----------
 
     def aug_rotate(self, img, pre_norm=False):
 
         """
-        Rotates the image by a random angle within the range given.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Rotates the image by a random angle within the range given
+        (set pre_norm to True if image has been normalized to [0,1]).
         """
 
         if self.rotate_range is not None:
-            rotate = iaa.Affine(rotate=self.rotate_range, mode="edge")
+            rotate = iaa.Affine(
+                rotate=self.rotate_range, mode=self.fill_mode
+            )
             if pre_norm:
                 img = (img * 255).astype(np.uint8)
                 rotated_img = (rotate(image=img)) / 255
@@ -472,12 +531,14 @@ class Augmenter:
 
         """
         Shear-transforms the image by a random angle within the range
-        given.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        given (set pre_norm to True if image has been normalized to
+        [0,1]).
         """
 
         if self.shear_range is not None:
-            shear = iaa.Affine(shear=self.shear_range, mode="edge")
+            shear = iaa.Affine(
+                shear=self.shear_range, mode=self.fill_mode
+            )
             if pre_norm:
                 img = (img * 255).astype(np.uint8)
                 shear_img = (shear(image=img)) / 255
@@ -492,12 +553,12 @@ class Augmenter:
     def aug_dropout(self, img, pre_norm=False):
 
         """
-        Drops a portion of pixel values to zero.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Drops a portion of pixel values to zero (set pre_norm to True
+        if image has been normalized to [0,1]).
         """
 
         if self.dropout_pair is not None:
-            if self.randomize_batch == True:
+            if self.randomize_params == True:
                 drop_1 = (
                     np.random.randint(0, self.dropout_pair[0] * 100)
                     / 100
@@ -523,16 +584,60 @@ class Augmenter:
 
     #     ----------
 
+    def aug_x_scale(self, img, pre_norm=False):
+
+        """
+        Scales (squashes or stretches) the image on the x-axis by a
+        random amount within the range given (set pre_norm to True
+        if image has been normalized to [0,1]).
+        """
+
+        if self.x_scale is not None:
+            x_scale = iaa.ScaleX(self.x_scale, mode=self.fill_mode)
+            if pre_norm:
+                img = (img * 255).astype(np.uint8)
+                x_scale_img = (x_scale(image=img)) / 255
+            else:
+                x_scale_img = x_scale(image=img)
+            return x_scale_img
+        else:
+            return img
+
+    #     ----------
+
+    def aug_y_scale(self, img, pre_norm=False):
+
+        """
+        Scales (squashes or stretches) the image on the y-axis by a
+        random amount within the range given (set pre_norm to True
+        if image has been normalized to [0,1]).
+        """
+
+        if self.y_scale is not None:
+            y_scale = iaa.ScaleY(self.y_scale, mode=self.fill_mode)
+            if pre_norm:
+                img = (img * 255).astype(np.uint8)
+                y_scale_img = (y_scale(image=img)) / 255
+            else:
+                y_scale_img = y_scale(image=img)
+            return y_scale_img
+        else:
+            return img
+
+    #     ----------
+
     def aug_x_shift(self, img, pre_norm=False):
 
         """
         Shifts the image on the x-axis by a random amount within the
-        range given.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        range given (set pre_norm to True if image has been
+        normalized to [0,1]).
         """
 
         if self.x_shift is not None:
-            x_shift = iaa.TranslateX(percent=self.x_shift, mode="edge")
+            x_shift = iaa.TranslateX(
+                percent=self.x_shift, mode=self.fill_mode
+            )
             if pre_norm:
                 img = (img * 255).astype(np.uint8)
                 x_shift_img = (x_shift(image=img)) / 255
@@ -548,12 +653,14 @@ class Augmenter:
 
         """
         Shifts the image on the y-axis by a random amount within the
-        range given.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        range given (set pre_norm to True if image has been
+        normalized to [0,1]).
         """
 
         if self.y_shift is not None:
-            y_shift = iaa.TranslateY(percent=self.y_shift, mode="edge")
+            y_shift = iaa.TranslateY(
+                percent=self.y_shift, mode=self.fill_mode
+            )
             if pre_norm:
                 img = (img * 255).astype(np.uint8)
                 y_shift_img = (y_shift(image=img)) / 255
@@ -569,8 +676,8 @@ class Augmenter:
 
         """
         Applies a CLAH equalization using a random clip limit within
-        the range given.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        the range given (set pre_norm to True if image has been
+        normalized to [0,1]).
         """
 
         if self.clip_limit is not None:
@@ -590,12 +697,14 @@ class Augmenter:
 
         """
         Shifts local pixel areas by a random amount within the range
-        given.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        given (set pre_norm to True if image has been normalized
+        to [0,1]).
         """
 
         if self.pwa_scale is not None:
-            pwa = iaa.PiecewiseAffine(scale=self.pwa_scale, mode="edge")
+            pwa = iaa.PiecewiseAffine(
+                scale=self.pwa_scale, mode=self.fill_mode
+            )
             if pre_norm:
                 img = (img * 255).astype(np.uint8)
                 pwa_img = (pwa(image=img)) / 255
@@ -610,8 +719,8 @@ class Augmenter:
     def aug_h_flip(self, img, pre_norm=False):
 
         """
-        Flips a random subset of images horizontally.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Flips a random subset of images horizontally (set pre_norm
+        to True if image has been normalized to [0,1]).
         """
 
         if self.h_flip is not None:
@@ -630,8 +739,8 @@ class Augmenter:
     def aug_v_flip(self, img, pre_norm=False):
 
         """
-        Flipts a random subset of images vertically.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Flipts a random subset of images vertically (set pre_norm
+        to True if image has been normalized to [0,1]).
         """
 
         if self.v_flip is not None:
@@ -650,13 +759,13 @@ class Augmenter:
     def aug_g_noise(self, img, pre_norm=False):
 
         """
-        Adds Gaussian noise to the image.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Adds Gaussian noise to the image (set pre_norm to True if
+        image has been normalized to [0,1]).
         """
 
         if self.g_sev is not None:
             rand_sev = np.random.randint(self.g_sev + 1)
-            if self.randomize_batch == True:
+            if self.randomize_params == True:
                 if rand_sev == 0:
                     g_noise = None
                 else:
@@ -684,13 +793,13 @@ class Augmenter:
     def aug_brightness(self, img, pre_norm=False):
 
         """
-        Adjusts brightness of the image.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Adjusts brightness of the image (set pre_norm to True if
+        image has been normalized to [0,1]).
         """
 
         if self.b_sev is not None:
             rand_sev = np.random.randint(self.b_sev + 1)
-            if self.randomize_batch == True:
+            if self.randomize_params == True:
                 if rand_sev == 0:
                     brightness = None
                 else:
@@ -718,13 +827,13 @@ class Augmenter:
     def aug_elastic(self, img, pre_norm=False):
 
         """
-        Applies elastic transformation to the image.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Applies elastic transformation to the image (set pre_norm
+        to True if image has been normalized to [0,1]).
         """
 
         if self.e_sev is not None:
             rand_sev = np.random.randint(self.e_sev + 1)
-            if self.randomize_batch == True:
+            if self.randomize_params == True:
                 if rand_sev == 0:
                     elastic = None
                 else:
@@ -752,13 +861,13 @@ class Augmenter:
     def aug_contrast(self, img, pre_norm=False):
 
         """
-        Adusts contrast to a random subset of images.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Adusts contrast to a random subset of images (set pre_norm
+        to True if image has been normalized to [0,1]).
         """
 
         if self.contrast == True:
             contrast = iaa.pillike.EnhanceContrast()
-            if self.randomize_batch == True:
+            if self.randomize_params == True:
                 if np.random.randint(2) == True:
                     if pre_norm:
                         img = (img * 255).astype(np.uint8)
@@ -786,13 +895,13 @@ class Augmenter:
     def aug_sharpness(self, img, pre_norm=False):
 
         """
-        Adjusts sharpness to a random subset of images.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Adjusts sharpness to a random subset of images (set pre_norm
+        to True if image has been normalized to [0,1]).
         """
 
         if self.sharpness == True:
             sharpness = iaa.pillike.EnhanceSharpness()
-            if self.randomize_batch == True:
+            if self.randomize_params == True:
                 if np.random.randint(2) == True:
                     if pre_norm:
                         img = (img * 255).astype(np.uint8)
@@ -817,17 +926,37 @@ class Augmenter:
 
     #     ----------
 
-    def simple_augment(self, img, pre_norm=False):
+    def simple_augment(self, img, order=None, pre_norm=False):
 
         """
-        Performs the augmentations (for which a parameter was provided)
-        in order.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Performs the augmentations (for which a parameter was provided) in
+        a particular order.
+
+        Arguments:
+            img (array): image to augment.
+
+        Keyword Arguments:
+            order (list) optional: list of indices (integer type) to
+            determine the order in which the transformation functions are
+            applied. Note that the transformation functions are ordered
+            alphabetically by default. Defaults to None.
+            -
+            pre_norm (bool) optional: whether or not the input image
+            pixel values have been normalized to the range [0,1]. If True,
+            the pixel values will be de-normalized prior to augmentation.
+            Defaults to False.
+
+        Returns:
+            Augmented image.
         """
         if pre_norm:
             img = (img * 255).astype(np.uint8)
-        order = np.arange(self.argno)
-        for i in order:
+
+        if order:
+            aug_order = order
+        else:
+            aug_order = np.arange(self.argno)
+        for i in aug_order:
             function = self.f_list[i]
             outp = function(img)
             img = outp
@@ -841,23 +970,39 @@ class Augmenter:
     def random_augment(self, img, full_set=True, pre_norm=False):
 
         """
-        Performs the augmentations (for which a parameter was provided)
-        in a random order.
-        Note: Set pre_norm to True if image has been normalized to [0,1].
+        Performs the augmentations (for which a parameter was provided) in
+        a random order.
+
+        Arguments:
+            img (array): image to augment.
+
+        Keyword Arguments:
+            full_set (bool) optional: whether or not to apply all of the
+            transformation functions for which a parameter was provided in
+            the constructor upon initialization. If False, will apply a
+            random subset of the transformations. Defaults to True.
+            -
+            pre_norm (bool) optional: whether or not the input image
+            pixel values have been normalized to the range [0,1]. If True,
+            the pixel values will be de-normalized prior to augmentation.
+            Defaults to False.
+
+        Returns:
+            Augmented image.
         """
         if pre_norm:
             img = (img * 255).astype(np.uint8)
         if full_set:
-            order = np.random.choice(
+            aug_order = np.random.choice(
                 np.arange(self.argno), size=self.argno, replace=False
             )
         else:
-            order = np.random.choice(
+            aug_order = np.random.choice(
                 np.arange(self.argno),
                 size=np.random.randint(self.argno),
                 replace=False,
             )
-        for i in order:
+        for i in aug_order:
             function = self.f_list[i]
             outp = function(img)
             img = outp
@@ -875,6 +1020,7 @@ class Augmenter:
         n_rows,
         n_cols,
         augment_type="random",
+        order=None,
         pre_norm=False,
     ):
 
@@ -911,10 +1057,16 @@ class Augmenter:
             for the display. If "simple", the simple_augment method
             will be used. Defaults to "random".
             -
-            pre_norm (bool) optional: whether or not the image data
-            has been normalized to the range [0,1]. If it has, not
-            setting this to True will result in error. Defaults to
-            False. Only relevant for "path" mode.
+            order (list) optional: list of indices (integer type) to
+            determine the order in which the transformation functions are
+            applied. Note that the transformation functions are ordered
+            alphabetically by default. Only relevant if using "simple"
+            as the "augment_type" (see above). Defaults to None.
+            -
+            pre_norm (bool) optional: whether or not the input image
+            pixel values have been normalized to the range [0,1]. If True,
+            the pixel values will be de-normalized prior to augmentation.
+            Only relevant if using "path" mode. Defaults to False.
 
         Returns:
             Visualization of randomly augmented image.
@@ -956,7 +1108,7 @@ class Augmenter:
         ax1.set_yticks([])
         for i in tqdm(range(2, (n_rows * n_cols) + 1)):
             if augment_type == "simple":
-                aug_img = self.simple_augment(img)
+                aug_img = self.simple_augment(img, order=order)
             else:
                 aug_img = self.random_augment(img)
             ax = fig.add_subplot(n_rows, n_cols, i)
@@ -972,6 +1124,8 @@ class Augmenter:
     def augment_flow(
         self,
         base_path,
+        augment_type="random",
+        order=None,
         class_selection=None,
         number=None,
         size=None,
@@ -1000,6 +1154,17 @@ class Augmenter:
             class subdirectories.
 
         Keyword Arguments:
+            augment_type (str) optional: either "random" or "simple".
+            If "random", the class' "random_augment" method will be used
+            for the augmentation. If "simple", the "simple_augment" method
+            will be used. Defaults to "random".
+            -
+            order (list) optional: list of indices (integer type) to
+            determine the order in which the transformation functions are
+            applied. Note that the transformation functions are ordered
+            alphabetically by default. Only relevant if using "simple"
+            as the "augment_type" (see above). Defaults to None.
+            -
             class_selection (list) optional: list of class names on which
             to perform the augmentation. If not given, will apply to all
             the classes in the dataset. Defaults to None.
@@ -1108,9 +1273,14 @@ class Augmenter:
                     enumerate(all_aug_indices[0]),
                     total=len(all_aug_indices[0]),
                 ):
-                    aug_img = self.random_augment(
-                        all_class_arrays[0][j]
-                    )
+                    if augment_type == "simple":
+                        aug_img = self.simple_augment(
+                            all_class_arrays[0][j], order=order
+                        )
+                    else:
+                        aug_img = self.random_augment(
+                            all_class_arrays[0][j]
+                        )
                     imageio.imwrite(f"{r}/aug_{i+1}.jpg", aug_img)
                     aug_imgs.append(aug_img)
                 print("Augmented images saved successfully.")
@@ -1121,9 +1291,14 @@ class Augmenter:
                         enumerate(all_aug_indices[x]),
                         total=len(all_aug_indices[x]),
                     ):
-                        aug_img = self.random_augment(
-                            all_class_arrays[x][j]
-                        )
+                        if augment_type == "simple":
+                            aug_img = self.simple_augment(
+                                all_class_arrays[x][j], order=order
+                            )
+                        else:
+                            aug_img = self.random_augment(
+                                all_class_arrays[x][j]
+                            )
                         imageio.imwrite(
                             f"{base_path}/{class_list[x]}/{class_list[x]}_aug_{i+1}.jpg",
                             aug_img,
@@ -1138,9 +1313,14 @@ class Augmenter:
                     enumerate(all_aug_indices[0]),
                     total=len(all_aug_indices[0]),
                 ):
-                    aug_img = self.random_augment(
-                        all_class_arrays[0][j]
-                    )
+                    if augment_type == "simple":
+                        aug_img = self.simple_augment(
+                            all_class_arrays[0][j], order=order
+                        )
+                    else:
+                        aug_img = self.random_augment(
+                            all_class_arrays[0][j]
+                        )
                     aug_imgs.append(aug_img)
 
             else:
@@ -1149,9 +1329,14 @@ class Augmenter:
                         enumerate(all_aug_indices[x]),
                         total=len(all_aug_indices[x]),
                     ):
-                        aug_img = self.random_augment(
-                            all_class_arrays[x][j]
-                        )
+                        if augment_type == "simple":
+                            aug_img = self.simple_augment(
+                                all_class_arrays[x][j], order=order
+                            )
+                        else:
+                            aug_img = self.random_augment(
+                                all_class_arrays[x][j]
+                            )
                         aug_imgs.append(aug_img)
 
             return np.array(aug_imgs)
